==> react-lds-8.7.0.tgz: package/es/components/PageHeader/ObjectHome.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ClickOutside } from '../ClickOutside';
import { ControlledMenu } from '../Menu';
import { IconButton } from '../Button';
import { MediaObject } from '../MediaObject';
import { Icon } from '../Icon';

var ObjectHome =
/*#__PURE__*/
function (_Component) {
  _inherits(ObjectHome, _Component);

  function ObjectHome(props, context) {
    var _this;

    _classCallCheck(this, ObjectHome);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ObjectHome).call(this, props, context));

    _defineProperty(_assertThisInitialized(_this), "onClickOutside", function () {
      _this.setState({
        menuIsOpen: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "toggleMenu", function () {
      return _this.setState(function (prevState) {
        return {
          menuIsOpen: !prevState.menuIsOpen
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "openMenu", function () {
      _this.setState({
        menuIsOpen: true
      });
    });

    _this.state = {
      menuIsOpen: false
    };
    return _this;
  }

  _createClass(ObjectHome, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          bottomButtons = _this$props.bottomButtons,
          children = _this$props.children,
          className = _this$props.className,
          closeOnClickOutside = _this$props.closeOnClickOutside,
          icon = _this$props.icon,
          info = _this$props.info,
          recordType = _this$props.recordType,
          title = _this$props.title,
          titleMenu = _this$props.titleMenu,
          topButtons = _this$props.topButtons,
          rest = _objectWithoutProperties(_this$props, ["bottomButtons", "children", "className", "closeOnClickOutside", "icon", "info", "recordType", "title", "titleMenu", "topButtons"]);

      var menuIsOpen = this.state.menuIsOpen;
      var sldsClasses = ['slds-page-header', className];
      var titleClasses = ['slds-page-header__title', 'slds-truncate', {
        'slds-text-link_faux': titleMenu
      }];
      return React.createElement("div", _extends({}, rest, {
        className: cx(sldsClasses)
      }), React.createElement("div", {
        className: "slds-page-header__row"
      }, React.createElement("div", {
        className: "slds-page-header__col-title"
      }, React.createElement(MediaObject, {
        figureLeft: icon ? React.createElement(Icon, {
          sprite: icon.sprite,
          icon: icon.icon,
          svgClassName: "slds-page-header__icon"
        }) : null
      }, React.createElement("div", {
        className: "slds-page-header__name"
      }, React.createElement("div", {
        className: "slds-page-header__name-title"
      }, React.createElement("h1", null, React.createElement("span", null, recordType), React.createElement("span", {
        className: cx(titleClasses),
        onClick: titleMenu && this.toggleMenu,
        title: title
      }, title))), titleMenu && React.createElement(ClickOutside, {
        className: "slds-page-header__name-switcher",
        onClickOutside: this.onClickOutside,
        condition: closeOnClickOutside && menuIsOpen
      }, React.createElement(ControlledMenu, {
        button: React.createElement(IconButton, {
          container: true,
          icon: "down",
          size: "small",
          sprite: "utility",
          onClick: this.toggleMenu
        }),
        isOpen: this.state.menuIsOpen
      }, titleMenu))))), topButtons && React.createElement("div", {
        className: "slds-page-header__col-actions"
      }, React.createElement("div", {
        className: "slds-page-header__controls"
      }, React.createElement("div", {
        className: "slds-page-header__control"
      }, topButtons)))), (info || bottomButtons) && React.createElement("div", {
        className: "slds-page-header__row"
      }, React.createElement("div", {
        className: "slds-page-header__col-meta"
      }, info && React.createElement("p", {
        className: "slds-page-header__meta-text"
      }, info)), React.createElement("div", {
        className: "slds-page-header__col-controls"
      }, bottomButtons && React.createElement("div", {
        className: "slds-page-header__controls"
      }, bottomButtons))), children);
    }
  }]);

  return ObjectHome;
}(Component);

_defineProperty(ObjectHome, "defaultProps", {
  bottomButtons: null,
  children: null,
  className: null,
  closeOnClickOutside: false,
  icon: null,
  info: null,
  titleMenu: null,
  topButtons: null
});

ObjectHome.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * bottom Buttons or ButtonGroup(s)
   */
  bottomButtons: PropTypes.node,

  /**
   * Additional PageHeader rows
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * Whether the menu closes automatically on an outside click
   */
  closeOnClickOutside: PropTypes.bool,

  /**
   * icon and sprite
   */
  icon: PropTypes.shape({
    sprite: PropTypes.string.isRequired,
    icon: PropTypes.string.isRequired
  }),

  /**
   * info that is displayed below the title
   */
  info: PropTypes.string,

  /**
   * record type header above the title
   */
  recordType: PropTypes.string.isRequired,

  /**
   * title
   */
  title: PropTypes.string.isRequired,

  /**
   * dropdown header menu that also get's triggered when a user clicks on the
   * title headline. Must be one or more instances of MenuItem/MenuSubHeader
   */
  titleMenu: PropTypes.node,

  /**
   * top Buttons or ButtonGroup(s)
   */
  topButtons: PropTypes.node
} : {};
export default ObjectHome;

==> react-lds-9.1.0.tgz: package/es/components/PageHeader/ObjectHome.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ClickOutside } from '../ClickOutside';
import { ControlledMenu } from '../Menu';
import { IconButton } from '../Button';
import { MediaObject } from '../MediaObject';
import { Icon } from '../Icon';
import { Grid } from '../Grid';

var ObjectHome =
/*#__PURE__*/
function (_Component) {
  _inherits(ObjectHome, _Component);

  function ObjectHome(props, context) {
    var _this;

    _classCallCheck(this, ObjectHome);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ObjectHome).call(this, props, context));

    _defineProperty(_assertThisInitialized(_this), "onClickOutside", function () {
      _this.setState({
        menuIsOpen: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "toggleMenu", function () {
      return _this.setState(function (prevState) {
        return {
          menuIsOpen: !prevState.menuIsOpen
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "openMenu", function () {
      _this.setState({
        menuIsOpen: true
      });
    });

    _this.state = {
      menuIsOpen: false
    };
    return _this;
  }

  _createClass(ObjectHome, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          bottomButtons = _this$props.bottomButtons,
          children = _this$props.children,
          className = _this$props.className,
          closeOnClickOutside = _this$props.closeOnClickOutside,
          icon = _this$props.icon,
          info = _this$props.info,
          recordType = _this$props.recordType,
          title = _this$props.title,
          titleMenu = _this$props.titleMenu,
          titleMenuAction = _this$props.titleMenuAction,
          topButtons = _this$props.topButtons,
          rest = _objectWithoutProperties(_this$props, ["bottomButtons", "children", "className", "closeOnClickOutside", "icon", "info", "recordType", "title", "titleMenu", "titleMenuAction", "topButtons"]);

      var menuIsOpen = this.state.menuIsOpen;
      var sldsClasses = ['slds-page-header', className];
      var titleClasses = ['slds-page-header__title', 'slds-truncate', {
        'slds-text-link_faux': titleMenu
      }];
      return React.createElement("div", _extends({}, rest, {
        className: cx(sldsClasses)
      }), React.createElement("div", {
        className: "slds-page-header__row"
      }, React.createElement("div", {
        className: "slds-page-header__col-title"
      }, React.createElement(MediaObject, {
        figureLeft: icon ? React.createElement(Icon, {
          sprite: icon.sprite,
          icon: icon.icon,
          svgClassName: "slds-page-header__icon"
        }) : null
      }, React.createElement("div", {
        className: "slds-page-header__name"
      }, React.createElement("div", {
        className: "slds-page-header__name-title"
      }, React.createElement("h1", null, React.createElement("span", null, recordType), React.createElement("span", {
        className: cx(titleClasses),
        onClick: titleMenu && this.toggleMenu,
        title: title
      }, title))), titleMenu && React.createElement(React.Fragment, null, React.createElement(ClickOutside, {
        className: "slds-page-header__name-switcher",
        onClickOutside: this.onClickOutside,
        condition: closeOnClickOutside && menuIsOpen
      }, React.createElement(ControlledMenu, {
        button: React.createElement(IconButton, {
          container: true,
          icon: "down",
          size: "small",
          sprite: "utility",
          onClick: this.toggleMenu
        }),
        isOpen: this.state.menuIsOpen
      }, titleMenu)), titleMenuAction && React.createElement(Grid, {
        className: "slds-p-left_xx-small",
        verticalAlign: "end"
      }, titleMenuAction))))), topButtons && React.createElement("div", {
        className: "slds-page-header__col-actions"
      }, React.createElement("div", {
        className: "slds-page-header__controls"
      }, React.createElement("div", {
        className: "slds-page-header__control"
      }, topButtons)))), (info || bottomButtons) && React.createElement("div", {
        className: "slds-page-header__row"
      }, React.createElement("div", {
        className: "slds-page-header__col-meta"
      }, info && React.createElement("p", {
        className: "slds-page-header__meta-text"
      }, info)), React.createElement("div", {
        className: "slds-page-header__col-controls"
      }, bottomButtons && React.createElement("div", {
        className: "slds-page-header__controls"
      }, bottomButtons))), children);
    }
  }]);

  return ObjectHome;
}(Component);

_defineProperty(ObjectHome, "defaultProps", {
  bottomButtons: null,
  children: null,
  className: null,
  closeOnClickOutside: false,
  icon: null,
  info: null,
  titleMenu: null,
  titleMenuAction: null,
  topButtons: null
});

ObjectHome.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * bottom Buttons or ButtonGroup(s)
   */
  bottomButtons: PropTypes.node,

  /**
   * Additional PageHeader rows
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * Whether the menu closes automatically on an outside click
   */
  closeOnClickOutside: PropTypes.bool,

  /**
   * icon and sprite
   */
  icon: PropTypes.shape({
    sprite: PropTypes.string.isRequired,
    icon: PropTypes.string.isRequired
  }),

  /**
   * info that is displayed below the title
   */
  info: PropTypes.string,

  /**
   * record type header above the title
   */
  recordType: PropTypes.string.isRequired,

  /**
   * title
   */
  title: PropTypes.string.isRequired,

  /**
   * dropdown header menu that also get's triggered when a user clicks on the
   * title headline. Must be one or more instances of MenuItem/MenuSubHeader
   */
  titleMenu: PropTypes.node,

  /**
   * optional title menu action that gets displayed beside the header menu.
   *
   * TODO The SLDS does not yet provide the specifications for the pin button,
   * once it does the structure should be updated accordingly.
   */
  titleMenuAction: PropTypes.node,

  /**
   * top Buttons or ButtonGroup(s)
   */
  topButtons: PropTypes.node
} : {};
export default ObjectHome;
